@@ -14,74 +14,86 @@
 
 
 class MobileCommand(object):
-    CONTEXTS = 'getContexts',
-    GET_CURRENT_CONTEXT = 'getCurrentContext',
-    SWITCH_TO_CONTEXT = 'switchToContext'
-    TOUCH_ACTION = 'touchAction'
-    MULTI_ACTION = 'multiAction'
-    OPEN_NOTIFICATIONS = 'openNotifications'
-    GET_NETWORK_CONNECTION = 'getNetworkConnection'
-    SET_NETWORK_CONNECTION = 'setNetworkConnection'
+    # Common
+    GET_LOCATION = 'getLocation'
+    SET_LOCATION = 'setLocation'
+
     GET_AVAILABLE_IME_ENGINES = 'getAvailableIMEEngines'
     IS_IME_ACTIVE = 'isIMEActive'
     ACTIVATE_IME_ENGINE = 'activateIMEEngine'
     DEACTIVATE_IME_ENGINE = 'deactivateIMEEngine'
     GET_ACTIVE_IME_ENGINE = 'getActiveEngine'
-    TOGGLE_LOCATION_SERVICES = 'toggleLocationServices'
-    TOGGLE_WIFI = 'toggleWiFi'
+
+    CLEAR = 'clear'
     LOCATION_IN_VIEW = 'locationInView'
 
-    # Appium Commands
-    GET_APP_STRINGS = 'getAppStrings'
-    PRESS_KEYCODE = 'pressKeyCode'
-    KEY_EVENT = 'keyEvent'  # Needed for Selendroid
-    LONG_PRESS_KEYCODE = 'longPressKeyCode'
-    GET_CURRENT_ACTIVITY = 'getCurrentActivity'
-    GET_CURRENT_PACKAGE = 'getCurrentPackage'
+    CONTEXTS = 'getContexts'
+    GET_CURRENT_CONTEXT = 'getCurrentContext'
+    SWITCH_TO_CONTEXT = 'switchToContext'
+
+    TOUCH_ACTION = 'touchAction'
+    MULTI_ACTION = 'multiAction'
+
     SET_IMMEDIATE_VALUE = 'setImmediateValue'
-    PULL_FILE = 'pullFile'
-    PULL_FOLDER = 'pullFolder'
-    PUSH_FILE = 'pushFile'
+    REPLACE_KEYS = 'replaceKeys'
+
+    LAUNCH_APP = 'launchApp'
+    CLOSE_APP = 'closeApp'
+    RESET = 'reset'
     BACKGROUND = 'background'
-    IS_APP_INSTALLED = 'isAppInstalled'
+    GET_APP_STRINGS = 'getAppStrings'
+
+    IS_LOCKED = 'isLocked'
+    LOCK = 'lock'
+    UNLOCK = 'unlock'
+    GET_DEVICE_TIME_GET = 'getDeviceTimeGet'
+    GET_DEVICE_TIME_POST = 'getDeviceTimePost'
     INSTALL_APP = 'installApp'
     REMOVE_APP = 'removeApp'
+    IS_APP_INSTALLED = 'isAppInstalled'
     TERMINATE_APP = 'terminateApp'
     ACTIVATE_APP = 'activateApp'
     QUERY_APP_STATE = 'queryAppState'
-    LAUNCH_APP = 'launchApp'
-    CLOSE_APP = 'closeApp'
-    END_TEST_COVERAGE = 'endTestCoverage'
-    LOCK = 'lock'
-    UNLOCK = 'unlock'
-    IS_LOCKED = 'isLocked'
     SHAKE = 'shake'
-    TOUCH_ID = 'touchId'
-    TOGGLE_TOUCH_ID_ENROLLMENT = 'toggleTouchIdEnrollment'
-    RESET = 'reset'
     HIDE_KEYBOARD = 'hideKeyboard'
-    IS_KEYBOARD_SHOWN = 'isKeyboardShown'
-    REPLACE_KEYS = 'replaceKeys'
-    START_ACTIVITY = 'startActivity'
+    PRESS_KEYCODE = 'pressKeyCode'
+    LONG_PRESS_KEYCODE = 'longPressKeyCode'
+    KEY_EVENT = 'keyEvent'  # Needed for Selendroid
+    PUSH_FILE = 'pushFile'
+    PULL_FILE = 'pullFile'
+    PULL_FOLDER = 'pullFolder'
+    GET_CLIPBOARD = 'getClipboard'
+    SET_CLIPBOARD = 'setClipboard'
+    FINGER_PRINT = 'fingerPrint'
     GET_SETTINGS = 'getSettings'
     UPDATE_SETTINGS = 'updateSettings'
-    SET_LOCATION = 'setLocation'
-    GET_LOCATION = 'getLocation'
-    GET_DEVICE_TIME_GET = 'getDeviceTimeGet'
-    GET_DEVICE_TIME_POST = 'getDeviceTimePost'
-    CLEAR = 'clear'
     START_RECORDING_SCREEN = 'startRecordingScreen'
     STOP_RECORDING_SCREEN = 'stopRecordingScreen'
-    SET_CLIPBOARD = 'setClipboard'
-    GET_CLIPBOARD = 'getClipboard'
     COMPARE_IMAGES = 'compareImages'
-    FINGER_PRINT = 'fingerPrint'
+    IS_KEYBOARD_SHOWN = 'isKeyboardShown'
+
+    # Android
+    OPEN_NOTIFICATIONS = 'openNotifications'
+    START_ACTIVITY = 'startActivity'
+    GET_CURRENT_ACTIVITY = 'getCurrentActivity'
+    GET_CURRENT_PACKAGE = 'getCurrentPackage'
+    GET_SYSTEM_BARS = 'getSystemBars'
+    TOGGLE_WIFI = 'toggleWiFi'
+    TOGGLE_LOCATION_SERVICES = 'toggleLocationServices'
+    END_TEST_COVERAGE = 'endTestCoverage'
+    GET_PERFORMANCE_DATA_TYPES = 'getPerformanceDataTypes'
+    GET_PERFORMANCE_DATA = 'getPerformanceData'
+    GET_NETWORK_CONNECTION = 'getNetworkConnection'
+    SET_NETWORK_CONNECTION = 'setNetworkConnection'
+
+    # Android Emulator
     SEND_SMS = 'sendSms'
+    MAKE_GSM_CALL = 'makeGsmCall'
+    SET_GSM_SIGNAL = 'setGsmSignal'
+    SET_GSM_VOICE = 'setGsmVoice'
     SET_POWER_CAPACITY = 'setPowerCapacity'
     SET_POWER_AC = 'setPowerAc'
-    SET_GSM_SIGNAL = 'setGsmSignal'
-    MAKE_GSM_CALL = 'makeGsmCall'
-    GET_SYSTEM_BARS = 'getSystemBars'
-    SET_GSM_VOICE = 'setGsmVoice'
-    GET_PERFORMANCE_DATA = 'getPerformanceData'
-    GET_PERFORMANCE_DATA_TYPES = 'getPerformanceDataTypes'
+
+    # iOS
+    TOUCH_ID = 'touchId'
+    TOGGLE_TOUCH_ID_ENROLLMENT = 'toggleTouchIdEnrollment'
